@@ -34,9 +34,4 @@ class dateCalc():
             monthdif = monthdif * 30.416
         daydif = int(bases[2]) - int(today[2])
         var = round((daydif+monthdif+yeardif),0)
-        return str(int(var)) 
-
-    x = 1/1/1
-    while x != '':
-        x = input('enter a date in year/month/day format: ')
-        print(str(x)+' is '+str(checkDate(x))+' days away.')
\ No newline at end of file
+        return str(int(var)) 
\ No newline at end of file
